@@ -7,10 +7,12 @@ use strict;
 use Exporter ();
 use vars qw($VERSION @ISA @EXPORT_OK);
 
-$VERSION = '0.20';
+$VERSION = '0.21';
 @ISA = 'Exporter';
 @EXPORT_OK = qw();
 
+=encoding utf-8
+
 =head1 NAME
 
 XML::TMX - Perl extensions for managing TMX files
@@ -27,19 +29,19 @@ any useful code, so check sub-modules, please.
 
 =head1 SEE ALSO
 
-XML::TMX::Writer, XML::TMX::Reader, XML::TMX::Query, XML::TMX::FromPO
+XML::TMX::Writer, XML::TMX::Reader, XML::TMX::FromPO
 
 L<XML::Writer(3)>, TMX Specification L<http://www.lisa.org/tmx/tmx.htm>
 
 =head1 AUTHOR
 
-Alberto Simes, E<lt>albie@alfarrabio.di.uminho.ptE<gt>
+Alberto Simões, E<lt>albie@alfarrabio.di.uminho.ptE<gt>
 
 Paulo Jorge Jesus Silva, E<lt>paulojjs@bragatel.ptE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2003 by Projecto Natura
+Copyright 2003-2012 by Projecto Natura
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
